@@ -24,28 +24,29 @@ from types import FunctionType
 from typing import TYPE_CHECKING, TypeVar, cast
 
 from .dbus_common_elements import (
-    DbusBindedSync,
+    DbusBoundSync,
+    DbusMemberSync,
     DbusMethodCommon,
-    DbusSomethingSync,
 )
 
 if TYPE_CHECKING:
-    from typing import Any, Callable, Optional, Sequence, Type
+    from collections.abc import Callable, Sequence
+    from typing import Any, Optional
 
     from .dbus_proxy_sync_interface_base import DbusInterfaceBase
 
 T = TypeVar('T')
 
 
-class DbusMethodSync(DbusMethodCommon, DbusSomethingSync):
+class DbusMethodSync(DbusMethodCommon, DbusMemberSync):
     def __get__(self,
                 obj: DbusInterfaceBase,
-                obj_class: Optional[Type[DbusInterfaceBase]] = None,
+                obj_class: Optional[type[DbusInterfaceBase]] = None,
                 ) -> Callable[..., Any]:
-        return DbusMethodSyncBinded(self, obj)
+        return DbusLocalMethodSync(self, obj)
 
 
-class DbusMethodSyncBinded(DbusBindedSync):
+class DbusLocalMethodSync(DbusBoundSync):
     def __init__(self,
                  dbus_method: DbusMethodSync,
                  interface: DbusInterfaceBase):
