@@ -49,7 +49,6 @@ class SdBusSlot:
 
 
 class SdBusInterface:
-    slot: Optional[SdBusSlot]
     method_list: list[object]
     method_dict: dict[bytes, object]
     property_list: list[object]
@@ -86,6 +85,9 @@ class SdBusInterface:
     ) -> None:
         raise NotImplementedError(__STUB_ERROR)
 
+    def _stop_export(self) -> None:
+        raise NotImplementedError(__STUB_ERROR)
+
 
 class SdBusMessage:
     def append_data(self, signature: str, *args: DbusCompleteTypes) -> None:
